==> igloo_0_1_2.zip: igloo_0_1_2/igloo/language/1/barnraiser_01/man/wiki.man.php <==
+++ Wiki
The Hawaiian term wiki wiki, meaning "quick" or "super-fast".

A wiki enables documents to be written collectively in a simple markup language using a web browser. A single page in a wiki is referred to as a "wiki page", while the entire body of pages, which are usually highly interconnected via hyperlinks, is called "the wiki."

A defining characteristic of wiki technology is the ease with which pages can be created and updated. Generally, there is no review before modifications are accepted.

You can use your wiki as a web site in which to write documents such as manuals, cv's or detailed information about your interests. You can add pictures to support your work.

++++ Wiki structures
Each wiki has a default page. It is the top page or the first page that you come to. You can create new pages and use the contents list to list them, however a wiki allows you to create links to pages from within other pages creating a powerful library of interlinked documents.

++++ WikiLinks
Creating the linking between pages is easy. Each page has a unique name (called it's wiki name). You define these when you make a new page. For instance if we are editing our default page we can write:

I am using Igloo software to write this. 

We want to make Igloo into a link to a new page that describes Igloo. We create links by using Studly Caps texts which LooksLikeThis so we can write 

I am using !IglooSoftware to write this. 

Igloo will now make !IglooSoftware into a link with a question mark after it like this !IglooSoftware? By pressing the question mark you create a new page. This means that you can create the link and someone else can create the page and enter the details later.

+++ Adding or Editing a wiki page
Whenever you edit a wiki page Igloo makes a new page and archives the previous copy so there is always a backup of your work. 

You can edit a wiki page by pressing 'Edit this' at the base of every wiki page or by entering the administration page. New pages can be created (without wiki linking) from the administation page.

Press the 'edit wiki pages' button under the 'structure' menu to enter the administration area. You will see a list of wiki pages. At the top you will see an 'add wiki page' button or press the link against each wiki page listed to edit it.

In the edit wiki page page you will see a series of fields which should be filled:

+++++ Wiki page
Type in your item details.  Included is a small formatting menu. See 'formatting a wiki page' for more information on the menu and the formatting options available to you in Igloo.

+++++ Note
You can leave a note for other authors explaining any changes you have made. This is only show in the edit screen.

+++++ Title
The page title will appear above each page. Enter a concise page title.

+++++ Synopsis
The synopsis is a short description of the wiki page. It will appear on listings and in search results.

+++++ Prefered language
If you have a multilingual installation of Igloo you will see a list of available languages. Select the language that best represents your wiki page content.

+++++ Allow comments checkbox
You can allow people to comment your wiki page. Check the 'allow comments' checkbox if you want to receive comment.

+++++ Default wiki page checkbox
The default page is the page which is displayed by default on the home page (when you first come to the site, it's the first page you see). Check the box to make this the default page. 

+++++ Wiki page field
The Wiki page is the page name that you can link to from within any page in beacon. It must be formatted in Studly caps which LooksLikeThis and it must be unique (Igloo will tell you if it is not).

+++++ Saving your wiki page 
You can save your page or 'save and go' (which will save the page and take you to the visitor display of the wiki page).

+++ Formatting a wiki page 
You can format wiki pages using the wiki formatting tools or by typing in wiki syntax. You can see the full syntax in the 'Formatting Guide'.

==> igloo_0_1_7.zip: igloo_0_1_7/igloo/language/1/barnraiser_01/man/wiki.man.php <==
+++ Wiki
The Hawaiian term wiki wiki, meaning "quick" or "super-fast".

A wiki enables documents to be written collectively in a simple markup language using a web browser. A single page in a wiki is referred to as a "wiki page", while the entire body of pages, which are usually highly interconnected via hyperlinks, is called "the wiki."

A defining characteristic of wiki technology is the ease with which pages can be created and updated. Generally, there is no review before modifications are accepted.

You can use your wiki as a web site in which to write documents such as manuals, cv's or detailed information about your interests. You can add pictures to support your work.

++++ Wiki structures
Each wiki has a default page. It is the top page or the first page that you come to. You can create new pages and use the contents list to list them, however a wiki allows you to create links to pages from within other pages creating a powerful library of interlinked documents.

++++ WikiLinks
Creating the linking between pages is easy. Each page has a unique name (called it's wiki name). You define these when you make a new page. For instance if we are editing our default page we can write:

I am using Igloo software to write this. 

We want to make Igloo into a link to a new page that describes Igloo. We create links by using Studly Caps texts which LooksLikeThis so we can write 

I am using IglooSoftware to write this. 

Igloo will now make IglooSoftware into a link with a question mark after it like this IglooSoftware? By pressing the question mark you create a new page. This means that you can create the link and someone else can create the page and enter the details later.

Please note: you can only use characters a-z, A-Z and 0-9 in Studly caps. You cannot use characters such as %,Å,ö.

+++ Adding or Editing a wiki page
Whenever you edit a wiki page Igloo makes a new page and archives the previous copy so there is always a backup of your work. 

You can edit a wiki page by pressing 'Edit this' at the base of every wiki page or by entering the administration page. New pages can be created (without wiki linking) from the administation page.

Press the 'edit wiki pages' button under the 'structure' menu to enter the administration area. You will see a list of wiki pages. At the top you will see an 'add wiki page' button or press the link against each wiki page listed to edit it.

In the edit wiki page page you will see a series of fields which should be filled:

+++++ Wiki page
Type in your item details.  Included is a small formatting menu. See 'formatting a wiki page' for more information on the menu and the formatting options available to you in Igloo.

+++++ Note
You can leave a note for other authors explaining any changes you have made. This is only show in the edit screen.

+++++ Title
The page title will appear above each page. Enter a concise page title.

+++++ Synopsis
The synopsis is a short description of the wiki page. It will appear on listings and in search results.

+++++ Prefered language
If you have a multilingual installation of Igloo you will see a list of available languages. Select the language that best represents your wiki page content.

+++++ Allow comments checkbox
You can allow people to comment your wiki page. Check the 'allow comments' checkbox if you want to receive comment.

+++++ Default wiki page checkbox
The default page is the page which is displayed by default on the home page (when you first come to the site, it's the first page you see). Check the box to make this the default page. 

+++++ Wiki page field
The Wiki page is the page name that you can link to from within any page in beacon. It must be formatted in Studly caps which LooksLikeThis and it must be unique (Igloo will tell you if it is not).

+++++ Saving your wiki page 
You can save your page or 'save and go' (which will save the page and take you to the visitor display of the wiki page).

+++ Formatting a wiki page 
You can format wiki pages using the wiki formatting tools or by typing in wiki syntax. You can see the full syntax in the 'Formatting Guide'.
